/*

  Graphic user's interface library
  List and Icon views base class

  Author(s): Alexander Volkov (support@rusbitech.ru)

  Start date: *

*/

#ifndef FLYFM_LISTANDICONVIEW_H
#define FLYFM_LISTANDICONVIEW_H

#include <QListView>

namespace FlyFM
{

class Entry;
class EntryList;
class DragAndDropHelper;

class ListAndIconView : public QListView
{
    Q_OBJECT

    friend class DragAndDropHelper;
    friend class ThumbnailItemDelegate;

public:
    ListAndIconView(QWidget *parent = nullptr);

    void setHorizontalScrollByWheel(bool enable);
    bool isHorizontalScrollByWheel() const;

public slots:
    void setIconSize(int size);

signals:
    void customPopupContextMenuRequested(const QPoint &, const QModelIndexList &);
    void dropContextMenuRequested(const QPoint &, Qt::DropActions, const EntryList &, const Entry &);
    void arkExtractContextMenuRequested(const QPoint &, const QString &dbusService, const QString &dbusPath, const Entry &dst);
    void openActionRequested(const QModelIndexList &);
    void upActionRequested();

protected slots:
    void customPopupContextMenu(const QPoint &);

    void openActionEmitter();
    void upActionEmitter();

protected:
    void startDrag(Qt::DropActions supportedActions) override;
    void resizeEvent(QResizeEvent *event) override;
    void wheelEvent(QWheelEvent *e) override;

private:
    bool m_horizontalScrollByWheel;
    DragAndDropHelper *m_dragAndDropHelper;
};
}

#endif // FLYFM_LISTANDICONVIEW_H
